@@ -20,9 +20,10 @@ from __future__ import absolute_import
 import logging
 import re
 
+from six.moves import range
+
 from mmcif.api.DataCategory import DataCategory
 
-from six.moves import range
 
 __docformat__ = "restructuredtext en"
 __author__ = "John Westbrook"
@@ -34,8 +35,7 @@ logger = logging.getLogger(__name__)
 
 
 class DataCategoryFormatted(DataCategory):
-    """  A subclass of DataCategory including additional formatting methods.
-    """
+    """A subclass of DataCategory including additional formatting methods."""
 
     def __init__(self, dataCategoryObj, preferDoubleQuotes=True):
         self.__dcObj = dataCategoryObj
@@ -96,8 +96,7 @@ class DataCategoryFormatted(DataCategory):
         # self.__string_types = basestring
 
     def __formatPdbx(self, inp):
-        """ Format input data following PDBx quoting rules -
-        """
+        """Format input data following PDBx quoting rules -"""
         try:
             if inp is None:
                 return ("?", "DT_NULL_VALUE")
@@ -181,8 +180,7 @@ class DataCategoryFormatted(DataCategory):
         return ("?", "DT_NULL_VALUE")
 
     def __dataTypePdbx(self, inp):
-        """ Detect the PDBx data type -
-        """
+        """Detect the PDBx data type -"""
         if inp is None:
             return "DT_NULL_VALUE"
 
